<template>
  <Dialog v-model="dialogVisible" :title="dialogTitle" width="50%">
    <el-form
      ref="formRef"
      v-loading="formLoading"
      :model="formData"
      :rules="formRules"
      label-width="120px"
    >
      <el-row>
        <el-col :span="12">
          <el-form-item label="预测项ID" prop="itemId">
            <el-input v-model="formData.itemId" placeholder="请输入预测项ID"/>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="输出ID" prop="outId">
            <el-input v-model="formData.outId" placeholder="请输入输出ID"/>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="12">
          <el-form-item label="取样长度" prop="sampleLength">
            <el-input-number v-model="formData.sampleLength" :min="1" clearable controls-position="right" style="width: 100%"/>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="值类型" prop="valueType">
            <el-input v-model="formData.valueType" placeholder="请输入值类型"/>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="12">
          <el-form-item label="开始统计时间" prop="beginTime">
            <el-input v-model="formData.beginTime" placeholder="请输入开始统计时间"/>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="精准误差" prop="inDeviation">
            <el-input v-model="formData.inDeviation" placeholder="请输入精准误差"/>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="12">
          <el-form-item label="精准度" prop="inAccuracyRate">
            <el-input v-model="formData.inAccuracyRate" placeholder="请输入精准度"/>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="不可信误差" prop="outDeviation">
            <el-input v-model="formData.outDeviation" placeholder="请输入不可信误差"/>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="12">
          <el-form-item label="不可信率" prop="outAccuracyRate">
            <el-input v-model="formData.outAccuracyRate" placeholder="请输入不可信率"/>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="是否启用" prop="isEnable">
            <el-select v-model="formData.isEnable" placeholder="请选择">
              <el-option
                v-for="dict in getIntDictOptions(DICT_TYPE.COM_IS_INT)"
                :key="dict.value"
                :label="dict.label"
                :value="dict.value"
              />
            </el-select>
          </el-form-item>
        </el-col>
      </el-row>
    </el-form>
    <template #footer>
      <el-button :disabled="formLoading" type="primary" @click="submitForm">确 定</el-button>
      <el-button @click="dialogVisible = false">取 消</el-button>
    </template>
  </Dialog>
</template>
<script lang="ts" setup>
import * as MmItemAccuracyRate from '@/api/model/pre/accuracy/rate'
import {DICT_TYPE, getIntDictOptions} from "@/utils/dict";

defineOptions({name: 'DataMmItemAccuracyRateForm'})

const {t} = useI18n() // 国际化
const message = useMessage() // 消息弹窗
const dialogVisible = ref(false) // 弹窗的是否展示
const dialogTitle = ref('') // 弹窗的标题
const formLoading = ref(false) // 表单的加载中：1）修改时的数据加载；2）提交的按钮禁用
const formType = ref('') // 表单的类型：create - 新增；update - 修改
const formData = ref({
  id: undefined,
  itemId: undefined,
  outId: undefined,
  sampleLength: undefined,
  valueType: undefined,
  beginTime: undefined,
  inDeviation: undefined,
  inAccuracyRate: undefined,
  outDeviation: undefined,
  outAccuracyRate: undefined,
  isEnable: undefined,
})
const formRules = reactive({
  itemId: [{required: true, message: '预测项ID不能为空', trigger: 'blur'}],
  outId: [{required: true, message: '输出ID不能为空', trigger: 'blur'}],
})
const formRef = ref() // 表单 Ref

/** 打开弹窗 */
const open = async (type: string, id?: number) => {
  dialogVisible.value = true
  dialogTitle.value = t('action.' + type)
  formType.value = type
  resetForm()
  // 修改时，设置数据
  if (id) {
    formLoading.value = true
    try {
      formData.value = await MmItemAccuracyRate.getMmItemAccuracyRate(id)
    } finally {
      formLoading.value = false
    }
  }
}
defineExpose({open}) // 提供 open 方法，用于打开弹窗

/** 提交表单 */
const emit = defineEmits(['success']) // 定义 success 事件，用于操作成功后的回调
const submitForm = async () => {
  // 校验表单
  if (!formRef) return
  const valid = await formRef.value.validate()
  if (!valid) return
  // 提交请求
  formLoading.value = true
  try {
    const data = formData.value as unknown as MmItemAccuracyRate.MmItemAccuracyRateVO
    if (formType.value === 'create') {
      await MmItemAccuracyRate.createMmItemAccuracyRate(data)
      message.success(t('common.createSuccess'))
    } else {
      await MmItemAccuracyRate.updateMmItemAccuracyRate(data)
      message.success(t('common.updateSuccess'))
    }
    dialogVisible.value = false
    // 发送操作成功的事件
    emit('success')
  } finally {
    formLoading.value = false
  }
}

/** 重置表单 */
const resetForm = () => {
  formData.value = {
    id: undefined,
    itemId: undefined,
    outId: undefined,
    sampleLength: undefined,
    valueType: undefined,
    beginTime: undefined,
    inDeviation: undefined,
    inAccuracyRate: undefined,
    outDeviation: undefined,
    outAccuracyRate: undefined,
    isEnable: undefined,
  }
  formRef.value?.resetFields()
}
</script>
